@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Folder Color 0.0.78
+# Folder Color 0.0.79
 # Copyright (C) 2012-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Folder Color is free software; you can redistribute it and/or modify
@@ -742,11 +742,18 @@ class GlobalColor:
         f.close()
         
         # Reload icon cache
-        os.system('gtk-update-icon-cache -q "%s"' % os.path.join(self.foldercolor.USER_PATH_THEME, name))
+        self._run_cmd(['gtk-update-icon-cache', '-q', os.path.join(self.foldercolor.USER_PATH_THEME, name)])
         
         # Set new local theme
         self._set_theme(name)
     
+    def _run_cmd(self, cmd): # Not necesary a reply
+        try:
+            proc = subprocess.Popen(cmd, shell=False)
+            proc.communicate()
+        except:
+            pass
+    
     def _get_folder_icon(self, folder=None, special=0):
         """Compose icon by default"""
         # Need hacks
@@ -776,11 +783,11 @@ class GlobalColor:
         return iconname
     
     def _set_theme(self, theme):
-        # GTK
-        os.system('gsettings set org.gnome.desktop.interface icon-theme "%s"' % theme)
+        theme_aux = '"' + theme + '"'
+        self._run_cmd(['gsettings', 'set', 'org.gnome.desktop.interface', 'icon-theme', theme_aux])
         # XFCE
-        os.system('xfconf-query -c xsettings -p /Net/IconThemeName -s "%s"' % theme)
+        self._run_cmd(['xfconf-query', '-c', 'xsettings', '-p', '/Net/IconThemeName', '-s', theme_aux])
         # MATE
-        os.system('gsettings set org.mate.interface icon-theme "%s"' % theme)
+        self._run_cmd(['gsettings', 'set', 'org.mate.interface', 'icon-theme', theme_aux])
         # cinnamon
-        os.system('gsettings set org.cinnamon.desktop.interface icon-theme "%s"' % theme)
+        self._run_cmd(['gsettings', 'set', 'org.cinnamon.desktop.interface', 'icon-theme', theme_aux])
